@@ -55,7 +55,7 @@ class Services(CrudComponent):
 
 class SpaceServices(Services):
     def list_create_url(self) -> str:
-        return self.parent_url
+        return "%s/%s" % (self.root.url, self.name)
 
 
 # SpaceExtension
@@ -67,7 +67,7 @@ class SpaceExtensions(CrudComponent):
     Entity = SpaceExtension
 
     def list_create_url(self) -> str:
-        return self.parent_url
+        return "%s/%s" % (self.root.url, self.name)
 
     def delete_url(self, id_name: str) -> str:
         return f"{self.parent_url}/{id_name}"
@@ -84,10 +84,7 @@ class ServicePlugins(CrudComponent):
     Entity = ServicePlugin
 
     def list_create_url(self) -> str:
-        return self.parent_url
-
-    def delete_url(self, id_name: str) -> str:
-        return f"{self.parent_url}/{id_name}"
+        return "%s/%s" % (self.root.url, self.name)
 
 
 # Domain
